@@ -8,6 +8,11 @@ exports["Africa/Accra"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("Africa/Accra", { abbr: true, expect: "Africa/Abidjan" }),
 
+	"1918" : helpers.makeTestYear("Africa/Accra", [
+		["1918-01-01T00:00:51+00:00", "23:59:59", "LMT", 52 / 60],
+		["1918-01-01T00:00:52+00:00", "00:00:52", "GMT", 0]
+	]),
+
 	"1920" : helpers.makeTestYear("Africa/Accra", [
 		["1920-08-31T23:59:59+00:00", "23:59:59", "GMT", 0],
 		["1920-09-01T00:00:00+00:00", "00:20:00", "+0020", -20],
@@ -164,6 +169,8 @@ exports["Africa/Accra"] = {
 
 	"1942" : helpers.makeTestYear("Africa/Accra", [
 		["1942-08-31T23:59:59+00:00", "23:59:59", "GMT", 0],
-		["1942-09-01T00:00:00+00:00", "00:20:00", "+0020", -20]
+		["1942-09-01T00:00:00+00:00", "00:20:00", "+0020", -20],
+		["1942-12-30T23:39:59+00:00", "23:59:59", "+0020", -20],
+		["1942-12-30T23:40:00+00:00", "23:40:00", "GMT", 0]
 	])
 };
\ No newline at end of file
