@@ -19,5 +19,10 @@ exports["Africa/Sao_Tome"] = {
 	"2018" : helpers.makeTestYear("Africa/Sao_Tome", [
 		["2018-01-01T00:59:59+00:00", "00:59:59", "GMT", 0],
 		["2018-01-01T01:00:00+00:00", "02:00:00", "WAT", -60]
+	]),
+
+	"2019" : helpers.makeTestYear("Africa/Sao_Tome", [
+		["2019-01-01T00:59:59+00:00", "01:59:59", "WAT", -60],
+		["2019-01-01T01:00:00+00:00", "01:00:00", "GMT", 0]
 	])
 };
\ No newline at end of file
