@@ -120,6 +120,8 @@ exports["Africa/Tunis"] = {
 
 	"2008" : helpers.makeTestYear("Africa/Tunis", [
 		["2008-03-30T00:59:59+00:00", "01:59:59", "CET", -60],
-		["2008-03-30T01:00:00+00:00", "03:00:00", "CEST", -120]
+		["2008-03-30T01:00:00+00:00", "03:00:00", "CEST", -120],
+		["2008-10-26T00:59:59+00:00", "02:59:59", "CEST", -120],
+		["2008-10-26T01:00:00+00:00", "02:00:00", "CET", -60]
 	])
 };
\ No newline at end of file
