@@ -225,5 +225,10 @@ exports["America/Argentina/San_Juan"] = {
 	"2007" : helpers.makeTestYear("America/Argentina/San_Juan", [
 		["2007-12-30T02:59:59+00:00", "23:59:59", "-03", 180],
 		["2007-12-30T03:00:00+00:00", "01:00:00", "-02", 120]
+	]),
+
+	"2008" : helpers.makeTestYear("America/Argentina/San_Juan", [
+		["2008-03-16T01:59:59+00:00", "23:59:59", "-02", 120],
+		["2008-03-16T02:00:00+00:00", "23:00:00", "-03", 180]
 	])
 };
\ No newline at end of file
