@@ -8,6 +8,11 @@ exports["America/Boa_Vista"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("America/Boa_Vista", { abbr: true, expect: "America/Santo_Domingo" }),
 
+	"1914" : helpers.makeTestYear("America/Boa_Vista", [
+		["1914-01-01T04:02:39+00:00", "23:59:59", "LMT", 14560 / 60],
+		["1914-01-01T04:02:40+00:00", "00:02:40", "-04", 240]
+	]),
+
 	"1931" : helpers.makeTestYear("America/Boa_Vista", [
 		["1931-10-03T14:59:59+00:00", "10:59:59", "-04", 240],
 		["1931-10-03T15:00:00+00:00", "12:00:00", "-03", 180]
@@ -127,6 +132,8 @@ exports["America/Boa_Vista"] = {
 		["2000-02-27T02:59:59+00:00", "23:59:59", "-03", 180],
 		["2000-02-27T03:00:00+00:00", "23:00:00", "-04", 240],
 		["2000-10-08T03:59:59+00:00", "23:59:59", "-04", 240],
-		["2000-10-08T04:00:00+00:00", "01:00:00", "-03", 180]
+		["2000-10-08T04:00:00+00:00", "01:00:00", "-03", 180],
+		["2000-10-15T02:59:59+00:00", "23:59:59", "-03", 180],
+		["2000-10-15T03:00:00+00:00", "23:00:00", "-04", 240]
 	])
 };
\ No newline at end of file
