@@ -3,7 +3,10 @@
 var helpers = require("../../helpers/helpers");
 
 exports["America/Halifax"] = {
-	"guess" : helpers.makeTestGuess("America/Halifax", { offset: true, abbr: true }),
+
+	"guess:by:offset" : helpers.makeTestGuess("America/Halifax", { offset: true }),
+
+	"guess:by:abbr" : helpers.makeTestGuess("America/Halifax", { abbr: true }),
 
 	"1902" : helpers.makeTestYear("America/Halifax", [
 		["1902-06-15T04:14:23+00:00", "23:59:59", "LMT", 15264 / 60],
