@@ -8,6 +8,11 @@ exports["America/Maceio"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("America/Maceio", { abbr: true, expect: "America/Fortaleza" }),
 
+	"1914" : helpers.makeTestYear("America/Maceio", [
+		["1914-01-01T02:22:51+00:00", "23:59:59", "LMT", 8572 / 60],
+		["1914-01-01T02:22:52+00:00", "23:22:52", "-03", 180]
+	]),
+
 	"1931" : helpers.makeTestYear("America/Maceio", [
 		["1931-10-03T13:59:59+00:00", "10:59:59", "-03", 180],
 		["1931-10-03T14:00:00+00:00", "12:00:00", "-02", 120]
@@ -159,5 +164,10 @@ exports["America/Maceio"] = {
 	"2001" : helpers.makeTestYear("America/Maceio", [
 		["2001-10-14T02:59:59+00:00", "23:59:59", "-03", 180],
 		["2001-10-14T03:00:00+00:00", "01:00:00", "-02", 120]
+	]),
+
+	"2002" : helpers.makeTestYear("America/Maceio", [
+		["2002-02-17T01:59:59+00:00", "23:59:59", "-02", 120],
+		["2002-02-17T02:00:00+00:00", "23:00:00", "-03", 180]
 	])
 };
\ No newline at end of file
