@@ -3,7 +3,10 @@
 var helpers = require("../../helpers/helpers");
 
 exports["America/St_Johns"] = {
-	"guess" : helpers.makeTestGuess("America/St_Johns", { offset: true, abbr: true }),
+
+	"guess:by:offset" : helpers.makeTestGuess("America/St_Johns", { offset: true }),
+
+	"guess:by:abbr" : helpers.makeTestGuess("America/St_Johns", { abbr: true }),
 
 	"1917" : helpers.makeTestYear("America/St_Johns", [
 		["1917-04-08T05:30:51+00:00", "01:59:59", "NST", 12652 / 60],
