@@ -8,6 +8,11 @@ exports["Antarctica/Davis"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("Antarctica/Davis", { abbr: true, expect: "Asia/Jakarta" }),
 
+	"1957" : helpers.makeTestYear("Antarctica/Davis", [
+		["1957-01-12T23:59:59+00:00", "23:59:59", "-00", 0],
+		["1957-01-13T00:00:00+00:00", "07:00:00", "+07", -420]
+	]),
+
 	"1964" : helpers.makeTestYear("Antarctica/Davis", [
 		["1964-10-31T16:59:59+00:00", "23:59:59", "+07", -420],
 		["1964-10-31T17:00:00+00:00", "17:00:00", "-00", 0]
@@ -31,5 +36,10 @@ exports["Antarctica/Davis"] = {
 	"2011" : helpers.makeTestYear("Antarctica/Davis", [
 		["2011-10-27T18:59:59+00:00", "01:59:59", "+07", -420],
 		["2011-10-27T19:00:00+00:00", "00:00:00", "+05", -300]
+	]),
+
+	"2012" : helpers.makeTestYear("Antarctica/Davis", [
+		["2012-02-21T19:59:59+00:00", "00:59:59", "+05", -300],
+		["2012-02-21T20:00:00+00:00", "03:00:00", "+07", -420]
 	])
 };
\ No newline at end of file
