@@ -4,9 +4,9 @@ var helpers = require("../../helpers/helpers");
 
 exports["Antarctica/Macquarie"] = {
 
-	"guess:by:offset" : helpers.makeTestGuess("Antarctica/Macquarie", { offset: true, expect: "Asia/Sakhalin" }),
+	"guess:by:offset" : helpers.makeTestGuess("Antarctica/Macquarie", { offset: true, expect: "Australia/Sydney" }),
 
-	"guess:by:abbr" : helpers.makeTestGuess("Antarctica/Macquarie", { abbr: true, expect: "Asia/Sakhalin" }),
+	"guess:by:abbr" : helpers.makeTestGuess("Antarctica/Macquarie", { abbr: true, expect: "Australia/Sydney" }),
 
 	"1916" : helpers.makeTestYear("Antarctica/Macquarie", [
 		["1916-09-30T15:59:59+00:00", "01:59:59", "AEST", -600],
@@ -327,8 +327,192 @@ exports["Antarctica/Macquarie"] = {
 		["2009-10-03T16:00:00+00:00", "03:00:00", "AEDT", -660]
 	]),
 
-	"2010" : helpers.makeTestYear("Antarctica/Macquarie", [
-		["2010-04-03T15:59:59+00:00", "02:59:59", "AEDT", -660],
-		["2010-04-03T16:00:00+00:00", "03:00:00", "+11", -660]
+	"2011" : helpers.makeTestYear("Antarctica/Macquarie", [
+		["2011-04-02T15:59:59+00:00", "02:59:59", "AEDT", -660],
+		["2011-04-02T16:00:00+00:00", "02:00:00", "AEST", -600],
+		["2011-10-01T15:59:59+00:00", "01:59:59", "AEST", -600],
+		["2011-10-01T16:00:00+00:00", "03:00:00", "AEDT", -660]
+	]),
+
+	"2012" : helpers.makeTestYear("Antarctica/Macquarie", [
+		["2012-03-31T15:59:59+00:00", "02:59:59", "AEDT", -660],
+		["2012-03-31T16:00:00+00:00", "02:00:00", "AEST", -600],
+		["2012-10-06T15:59:59+00:00", "01:59:59", "AEST", -600],
+		["2012-10-06T16:00:00+00:00", "03:00:00", "AEDT", -660]
+	]),
+
+	"2013" : helpers.makeTestYear("Antarctica/Macquarie", [
+		["2013-04-06T15:59:59+00:00", "02:59:59", "AEDT", -660],
+		["2013-04-06T16:00:00+00:00", "02:00:00", "AEST", -600],
+		["2013-10-05T15:59:59+00:00", "01:59:59", "AEST", -600],
+		["2013-10-05T16:00:00+00:00", "03:00:00", "AEDT", -660]
+	]),
+
+	"2014" : helpers.makeTestYear("Antarctica/Macquarie", [
+		["2014-04-05T15:59:59+00:00", "02:59:59", "AEDT", -660],
+		["2014-04-05T16:00:00+00:00", "02:00:00", "AEST", -600],
+		["2014-10-04T15:59:59+00:00", "01:59:59", "AEST", -600],
+		["2014-10-04T16:00:00+00:00", "03:00:00", "AEDT", -660]
+	]),
+
+	"2015" : helpers.makeTestYear("Antarctica/Macquarie", [
+		["2015-04-04T15:59:59+00:00", "02:59:59", "AEDT", -660],
+		["2015-04-04T16:00:00+00:00", "02:00:00", "AEST", -600],
+		["2015-10-03T15:59:59+00:00", "01:59:59", "AEST", -600],
+		["2015-10-03T16:00:00+00:00", "03:00:00", "AEDT", -660]
+	]),
+
+	"2016" : helpers.makeTestYear("Antarctica/Macquarie", [
+		["2016-04-02T15:59:59+00:00", "02:59:59", "AEDT", -660],
+		["2016-04-02T16:00:00+00:00", "02:00:00", "AEST", -600],
+		["2016-10-01T15:59:59+00:00", "01:59:59", "AEST", -600],
+		["2016-10-01T16:00:00+00:00", "03:00:00", "AEDT", -660]
+	]),
+
+	"2017" : helpers.makeTestYear("Antarctica/Macquarie", [
+		["2017-04-01T15:59:59+00:00", "02:59:59", "AEDT", -660],
+		["2017-04-01T16:00:00+00:00", "02:00:00", "AEST", -600],
+		["2017-09-30T15:59:59+00:00", "01:59:59", "AEST", -600],
+		["2017-09-30T16:00:00+00:00", "03:00:00", "AEDT", -660]
+	]),
+
+	"2018" : helpers.makeTestYear("Antarctica/Macquarie", [
+		["2018-03-31T15:59:59+00:00", "02:59:59", "AEDT", -660],
+		["2018-03-31T16:00:00+00:00", "02:00:00", "AEST", -600],
+		["2018-10-06T15:59:59+00:00", "01:59:59", "AEST", -600],
+		["2018-10-06T16:00:00+00:00", "03:00:00", "AEDT", -660]
+	]),
+
+	"2019" : helpers.makeTestYear("Antarctica/Macquarie", [
+		["2019-04-06T15:59:59+00:00", "02:59:59", "AEDT", -660],
+		["2019-04-06T16:00:00+00:00", "02:00:00", "AEST", -600],
+		["2019-10-05T15:59:59+00:00", "01:59:59", "AEST", -600],
+		["2019-10-05T16:00:00+00:00", "03:00:00", "AEDT", -660]
+	]),
+
+	"2020" : helpers.makeTestYear("Antarctica/Macquarie", [
+		["2020-04-04T15:59:59+00:00", "02:59:59", "AEDT", -660],
+		["2020-04-04T16:00:00+00:00", "02:00:00", "AEST", -600],
+		["2020-10-03T15:59:59+00:00", "01:59:59", "AEST", -600],
+		["2020-10-03T16:00:00+00:00", "03:00:00", "AEDT", -660]
+	]),
+
+	"2021" : helpers.makeTestYear("Antarctica/Macquarie", [
+		["2021-04-03T15:59:59+00:00", "02:59:59", "AEDT", -660],
+		["2021-04-03T16:00:00+00:00", "02:00:00", "AEST", -600],
+		["2021-10-02T15:59:59+00:00", "01:59:59", "AEST", -600],
+		["2021-10-02T16:00:00+00:00", "03:00:00", "AEDT", -660]
+	]),
+
+	"2022" : helpers.makeTestYear("Antarctica/Macquarie", [
+		["2022-04-02T15:59:59+00:00", "02:59:59", "AEDT", -660],
+		["2022-04-02T16:00:00+00:00", "02:00:00", "AEST", -600],
+		["2022-10-01T15:59:59+00:00", "01:59:59", "AEST", -600],
+		["2022-10-01T16:00:00+00:00", "03:00:00", "AEDT", -660]
+	]),
+
+	"2023" : helpers.makeTestYear("Antarctica/Macquarie", [
+		["2023-04-01T15:59:59+00:00", "02:59:59", "AEDT", -660],
+		["2023-04-01T16:00:00+00:00", "02:00:00", "AEST", -600],
+		["2023-09-30T15:59:59+00:00", "01:59:59", "AEST", -600],
+		["2023-09-30T16:00:00+00:00", "03:00:00", "AEDT", -660]
+	]),
+
+	"2024" : helpers.makeTestYear("Antarctica/Macquarie", [
+		["2024-04-06T15:59:59+00:00", "02:59:59", "AEDT", -660],
+		["2024-04-06T16:00:00+00:00", "02:00:00", "AEST", -600],
+		["2024-10-05T15:59:59+00:00", "01:59:59", "AEST", -600],
+		["2024-10-05T16:00:00+00:00", "03:00:00", "AEDT", -660]
+	]),
+
+	"2025" : helpers.makeTestYear("Antarctica/Macquarie", [
+		["2025-04-05T15:59:59+00:00", "02:59:59", "AEDT", -660],
+		["2025-04-05T16:00:00+00:00", "02:00:00", "AEST", -600],
+		["2025-10-04T15:59:59+00:00", "01:59:59", "AEST", -600],
+		["2025-10-04T16:00:00+00:00", "03:00:00", "AEDT", -660]
+	]),
+
+	"2026" : helpers.makeTestYear("Antarctica/Macquarie", [
+		["2026-04-04T15:59:59+00:00", "02:59:59", "AEDT", -660],
+		["2026-04-04T16:00:00+00:00", "02:00:00", "AEST", -600],
+		["2026-10-03T15:59:59+00:00", "01:59:59", "AEST", -600],
+		["2026-10-03T16:00:00+00:00", "03:00:00", "AEDT", -660]
+	]),
+
+	"2027" : helpers.makeTestYear("Antarctica/Macquarie", [
+		["2027-04-03T15:59:59+00:00", "02:59:59", "AEDT", -660],
+		["2027-04-03T16:00:00+00:00", "02:00:00", "AEST", -600],
+		["2027-10-02T15:59:59+00:00", "01:59:59", "AEST", -600],
+		["2027-10-02T16:00:00+00:00", "03:00:00", "AEDT", -660]
+	]),
+
+	"2028" : helpers.makeTestYear("Antarctica/Macquarie", [
+		["2028-04-01T15:59:59+00:00", "02:59:59", "AEDT", -660],
+		["2028-04-01T16:00:00+00:00", "02:00:00", "AEST", -600],
+		["2028-09-30T15:59:59+00:00", "01:59:59", "AEST", -600],
+		["2028-09-30T16:00:00+00:00", "03:00:00", "AEDT", -660]
+	]),
+
+	"2029" : helpers.makeTestYear("Antarctica/Macquarie", [
+		["2029-03-31T15:59:59+00:00", "02:59:59", "AEDT", -660],
+		["2029-03-31T16:00:00+00:00", "02:00:00", "AEST", -600],
+		["2029-10-06T15:59:59+00:00", "01:59:59", "AEST", -600],
+		["2029-10-06T16:00:00+00:00", "03:00:00", "AEDT", -660]
+	]),
+
+	"2030" : helpers.makeTestYear("Antarctica/Macquarie", [
+		["2030-04-06T15:59:59+00:00", "02:59:59", "AEDT", -660],
+		["2030-04-06T16:00:00+00:00", "02:00:00", "AEST", -600],
+		["2030-10-05T15:59:59+00:00", "01:59:59", "AEST", -600],
+		["2030-10-05T16:00:00+00:00", "03:00:00", "AEDT", -660]
+	]),
+
+	"2031" : helpers.makeTestYear("Antarctica/Macquarie", [
+		["2031-04-05T15:59:59+00:00", "02:59:59", "AEDT", -660],
+		["2031-04-05T16:00:00+00:00", "02:00:00", "AEST", -600],
+		["2031-10-04T15:59:59+00:00", "01:59:59", "AEST", -600],
+		["2031-10-04T16:00:00+00:00", "03:00:00", "AEDT", -660]
+	]),
+
+	"2032" : helpers.makeTestYear("Antarctica/Macquarie", [
+		["2032-04-03T15:59:59+00:00", "02:59:59", "AEDT", -660],
+		["2032-04-03T16:00:00+00:00", "02:00:00", "AEST", -600],
+		["2032-10-02T15:59:59+00:00", "01:59:59", "AEST", -600],
+		["2032-10-02T16:00:00+00:00", "03:00:00", "AEDT", -660]
+	]),
+
+	"2033" : helpers.makeTestYear("Antarctica/Macquarie", [
+		["2033-04-02T15:59:59+00:00", "02:59:59", "AEDT", -660],
+		["2033-04-02T16:00:00+00:00", "02:00:00", "AEST", -600],
+		["2033-10-01T15:59:59+00:00", "01:59:59", "AEST", -600],
+		["2033-10-01T16:00:00+00:00", "03:00:00", "AEDT", -660]
+	]),
+
+	"2034" : helpers.makeTestYear("Antarctica/Macquarie", [
+		["2034-04-01T15:59:59+00:00", "02:59:59", "AEDT", -660],
+		["2034-04-01T16:00:00+00:00", "02:00:00", "AEST", -600],
+		["2034-09-30T15:59:59+00:00", "01:59:59", "AEST", -600],
+		["2034-09-30T16:00:00+00:00", "03:00:00", "AEDT", -660]
+	]),
+
+	"2035" : helpers.makeTestYear("Antarctica/Macquarie", [
+		["2035-03-31T15:59:59+00:00", "02:59:59", "AEDT", -660],
+		["2035-03-31T16:00:00+00:00", "02:00:00", "AEST", -600],
+		["2035-10-06T15:59:59+00:00", "01:59:59", "AEST", -600],
+		["2035-10-06T16:00:00+00:00", "03:00:00", "AEDT", -660]
+	]),
+
+	"2036" : helpers.makeTestYear("Antarctica/Macquarie", [
+		["2036-04-05T15:59:59+00:00", "02:59:59", "AEDT", -660],
+		["2036-04-05T16:00:00+00:00", "02:00:00", "AEST", -600],
+		["2036-10-04T15:59:59+00:00", "01:59:59", "AEST", -600],
+		["2036-10-04T16:00:00+00:00", "03:00:00", "AEDT", -660]
+	]),
+
+	"2037" : helpers.makeTestYear("Antarctica/Macquarie", [
+		["2037-04-04T15:59:59+00:00", "02:59:59", "AEDT", -660],
+		["2037-04-04T16:00:00+00:00", "02:00:00", "AEST", -600],
+		["2037-10-03T15:59:59+00:00", "01:59:59", "AEST", -600],
+		["2037-10-03T16:00:00+00:00", "03:00:00", "AEDT", -660]
 	])
 };
\ No newline at end of file
