@@ -8,6 +8,11 @@ exports["Asia/Karachi"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("Asia/Karachi", { abbr: true }),
 
+	"1906" : helpers.makeTestYear("Asia/Karachi", [
+		["1906-12-31T19:31:47+00:00", "23:59:59", "LMT", -16092 / 60],
+		["1906-12-31T19:31:48+00:00", "01:01:48", "+0530", -330]
+	]),
+
 	"1942" : helpers.makeTestYear("Asia/Karachi", [
 		["1942-08-31T18:29:59+00:00", "23:59:59", "+0530", -330],
 		["1942-08-31T18:30:00+00:00", "01:00:00", "+0630", -390]
@@ -44,6 +49,8 @@ exports["Asia/Karachi"] = {
 
 	"2009" : helpers.makeTestYear("Asia/Karachi", [
 		["2009-04-14T18:59:59+00:00", "23:59:59", "PKT", -300],
-		["2009-04-14T19:00:00+00:00", "01:00:00", "PKST", -360]
+		["2009-04-14T19:00:00+00:00", "01:00:00", "PKST", -360],
+		["2009-10-31T17:59:59+00:00", "23:59:59", "PKST", -360],
+		["2009-10-31T18:00:00+00:00", "23:00:00", "PKT", -300]
 	])
 };
\ No newline at end of file
