@@ -8,6 +8,11 @@ exports["Asia/Novokuznetsk"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("Asia/Novokuznetsk", { abbr: true, expect: "Asia/Jakarta" }),
 
+	"1924" : helpers.makeTestYear("Asia/Novokuznetsk", [
+		["1924-04-30T18:11:11+00:00", "23:59:59", "LMT", -20928 / 60],
+		["1924-04-30T18:11:12+00:00", "00:11:12", "+06", -360]
+	]),
+
 	"1930" : helpers.makeTestYear("Asia/Novokuznetsk", [
 		["1930-06-20T17:59:59+00:00", "23:59:59", "+06", -360],
 		["1930-06-20T18:00:00+00:00", "01:00:00", "+07", -420]
@@ -223,5 +228,10 @@ exports["Asia/Novokuznetsk"] = {
 		["2010-03-27T19:00:00+00:00", "02:00:00", "+07", -420],
 		["2010-10-30T19:59:59+00:00", "02:59:59", "+07", -420],
 		["2010-10-30T20:00:00+00:00", "02:00:00", "+06", -360]
+	]),
+
+	"2011" : helpers.makeTestYear("Asia/Novokuznetsk", [
+		["2011-03-26T19:59:59+00:00", "01:59:59", "+06", -360],
+		["2011-03-26T20:00:00+00:00", "03:00:00", "+07", -420]
 	])
 };
\ No newline at end of file
