@@ -8,6 +8,11 @@ exports["Asia/Omsk"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("Asia/Omsk", { abbr: true, expect: "Asia/Dhaka" }),
 
+	"1919" : helpers.makeTestYear("Asia/Omsk", [
+		["1919-11-13T19:06:29+00:00", "23:59:59", "LMT", -17610 / 60],
+		["1919-11-13T19:06:30+00:00", "00:06:30", "+05", -300]
+	]),
+
 	"1930" : helpers.makeTestYear("Asia/Omsk", [
 		["1930-06-20T18:59:59+00:00", "23:59:59", "+05", -300],
 		["1930-06-20T19:00:00+00:00", "01:00:00", "+06", -360]
@@ -228,5 +233,10 @@ exports["Asia/Omsk"] = {
 	"2011" : helpers.makeTestYear("Asia/Omsk", [
 		["2011-03-26T19:59:59+00:00", "01:59:59", "+06", -360],
 		["2011-03-26T20:00:00+00:00", "03:00:00", "+07", -420]
+	]),
+
+	"2014" : helpers.makeTestYear("Asia/Omsk", [
+		["2014-10-25T18:59:59+00:00", "01:59:59", "+07", -420],
+		["2014-10-25T19:00:00+00:00", "01:00:00", "+06", -360]
 	])
 };
\ No newline at end of file
