@@ -69,5 +69,10 @@ exports["Australia/Brisbane"] = {
 		["1991-03-02T16:00:00+00:00", "02:00:00", "AEST", -600],
 		["1991-10-26T15:59:59+00:00", "01:59:59", "AEST", -600],
 		["1991-10-26T16:00:00+00:00", "03:00:00", "AEDT", -660]
+	]),
+
+	"1992" : helpers.makeTestYear("Australia/Brisbane", [
+		["1992-02-29T15:59:59+00:00", "02:59:59", "AEDT", -660],
+		["1992-02-29T16:00:00+00:00", "02:00:00", "AEST", -600]
 	])
 };
\ No newline at end of file
