@@ -3,6 +3,11 @@
 var helpers = require("../../helpers/helpers");
 
 exports["Australia/Lord_Howe"] = {
+
+	"guess:by:offset" : helpers.makeTestGuess("Australia/Lord_Howe", { offset: true }),
+
+	"guess:by:abbr" : helpers.makeTestGuess("Australia/Lord_Howe", { abbr: true }),
+
 	"1981" : helpers.makeTestYear("Australia/Lord_Howe", [
 		["1981-02-28T13:59:59+00:00", "23:59:59", "AEST", -600],
 		["1981-02-28T14:00:00+00:00", "00:30:00", "+1030", -630],
