@@ -3,7 +3,10 @@
 var helpers = require("../../helpers/helpers");
 
 exports["Australia/Sydney"] = {
-	"guess" : helpers.makeTestGuess("Australia/Sydney", { offset: true, abbr: true }),
+
+	"guess:by:offset" : helpers.makeTestGuess("Australia/Sydney", { offset: true }),
+
+	"guess:by:abbr" : helpers.makeTestGuess("Australia/Sydney", { abbr: true }),
 
 	"1916" : helpers.makeTestYear("Australia/Sydney", [
 		["1916-12-31T14:00:59+00:00", "00:00:59", "AEST", -600],
