@@ -8,6 +8,11 @@ exports["Europe/Samara"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("Europe/Samara", { abbr: true, expect: "Asia/Dubai" }),
 
+	"1919" : helpers.makeTestYear("Europe/Samara", [
+		["1919-06-30T23:59:59+00:00", "03:20:19", "LMT", -12020 / 60],
+		["1919-07-01T00:00:00+00:00", "03:00:00", "+03", -180]
+	]),
+
 	"1930" : helpers.makeTestYear("Europe/Samara", [
 		["1930-06-20T20:59:59+00:00", "23:59:59", "+03", -180],
 		["1930-06-20T21:00:00+00:00", "01:00:00", "+04", -240]
@@ -223,5 +228,10 @@ exports["Europe/Samara"] = {
 		["2010-03-27T22:00:00+00:00", "02:00:00", "+04", -240],
 		["2010-10-30T22:59:59+00:00", "02:59:59", "+04", -240],
 		["2010-10-30T23:00:00+00:00", "02:00:00", "+03", -180]
+	]),
+
+	"2011" : helpers.makeTestYear("Europe/Samara", [
+		["2011-03-26T22:59:59+00:00", "01:59:59", "+03", -180],
+		["2011-03-26T23:00:00+00:00", "03:00:00", "+04", -240]
 	])
 };
\ No newline at end of file
