@@ -3,6 +3,11 @@
 var helpers = require("../../helpers/helpers");
 
 exports["Europe/Tirane"] = {
+
+	"guess:by:offset" : helpers.makeTestGuess("Europe/Tirane", { offset: true, expect: "Europe/Paris" }),
+
+	"guess:by:abbr" : helpers.makeTestGuess("Europe/Tirane", { abbr: true, expect: "Europe/Paris" }),
+
 	"1913" : helpers.makeTestYear("Europe/Tirane", [
 		["1913-12-31T22:40:39+00:00", "23:59:59", "LMT", -4760 / 60],
 		["1913-12-31T22:40:40+00:00", "23:40:40", "CET", -60]
