@@ -8,67 +8,72 @@ exports["Hongkong"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("Hongkong", { abbr: true, expect: "Asia/Hong_Kong" }),
 
+	"1904" : helpers.makeTestYear("Hongkong", [
+		["1904-10-29T16:59:59+00:00", "00:36:41", "LMT", -27402 / 60],
+		["1904-10-29T17:00:00+00:00", "01:00:00", "HKT", -480]
+	]),
+
 	"1941" : helpers.makeTestYear("Hongkong", [
-		["1941-06-14T19:29:59+00:00", "03:29:59", "HKT", -480],
-		["1941-06-14T19:30:00+00:00", "04:30:00", "HKST", -540],
+		["1941-06-14T18:59:59+00:00", "02:59:59", "HKT", -480],
+		["1941-06-14T19:00:00+00:00", "04:00:00", "HKST", -540],
 		["1941-09-30T18:59:59+00:00", "03:59:59", "HKST", -540],
-		["1941-09-30T19:00:00+00:00", "03:30:00", "HKT", -510],
-		["1941-12-24T15:29:59+00:00", "23:59:59", "HKT", -510],
+		["1941-09-30T19:00:00+00:00", "03:30:00", "HKWT", -510],
+		["1941-12-24T15:29:59+00:00", "23:59:59", "HKWT", -510],
 		["1941-12-24T15:30:00+00:00", "00:30:00", "JST", -540]
 	]),
 
 	"1945" : helpers.makeTestYear("Hongkong", [
-		["1945-09-15T14:59:59+00:00", "23:59:59", "JST", -540],
-		["1945-09-15T15:00:00+00:00", "23:00:00", "HKT", -480]
+		["1945-11-17T16:59:59+00:00", "01:59:59", "JST", -540],
+		["1945-11-17T17:00:00+00:00", "01:00:00", "HKT", -480]
 	]),
 
 	"1946" : helpers.makeTestYear("Hongkong", [
-		["1946-04-19T19:29:59+00:00", "03:29:59", "HKT", -480],
-		["1946-04-19T19:30:00+00:00", "04:30:00", "HKST", -540],
-		["1946-11-30T18:29:59+00:00", "03:29:59", "HKST", -540],
-		["1946-11-30T18:30:00+00:00", "02:30:00", "HKT", -480]
+		["1946-04-20T15:59:59+00:00", "23:59:59", "HKT", -480],
+		["1946-04-20T16:00:00+00:00", "01:00:00", "HKST", -540],
+		["1946-11-30T19:29:59+00:00", "04:29:59", "HKST", -540],
+		["1946-11-30T19:30:00+00:00", "03:30:00", "HKT", -480]
 	]),
 
 	"1947" : helpers.makeTestYear("Hongkong", [
 		["1947-04-12T19:29:59+00:00", "03:29:59", "HKT", -480],
 		["1947-04-12T19:30:00+00:00", "04:30:00", "HKST", -540],
-		["1947-12-29T18:29:59+00:00", "03:29:59", "HKST", -540],
-		["1947-12-29T18:30:00+00:00", "02:30:00", "HKT", -480]
+		["1947-11-29T19:29:59+00:00", "04:29:59", "HKST", -540],
+		["1947-11-29T19:30:00+00:00", "03:30:00", "HKT", -480]
 	]),
 
 	"1948" : helpers.makeTestYear("Hongkong", [
 		["1948-05-01T19:29:59+00:00", "03:29:59", "HKT", -480],
 		["1948-05-01T19:30:00+00:00", "04:30:00", "HKST", -540],
-		["1948-10-30T18:29:59+00:00", "03:29:59", "HKST", -540],
-		["1948-10-30T18:30:00+00:00", "02:30:00", "HKT", -480]
+		["1948-10-30T19:29:59+00:00", "04:29:59", "HKST", -540],
+		["1948-10-30T19:30:00+00:00", "03:30:00", "HKT", -480]
 	]),
 
 	"1949" : helpers.makeTestYear("Hongkong", [
 		["1949-04-02T19:29:59+00:00", "03:29:59", "HKT", -480],
 		["1949-04-02T19:30:00+00:00", "04:30:00", "HKST", -540],
-		["1949-10-29T18:29:59+00:00", "03:29:59", "HKST", -540],
-		["1949-10-29T18:30:00+00:00", "02:30:00", "HKT", -480]
+		["1949-10-29T19:29:59+00:00", "04:29:59", "HKST", -540],
+		["1949-10-29T19:30:00+00:00", "03:30:00", "HKT", -480]
 	]),
 
 	"1950" : helpers.makeTestYear("Hongkong", [
 		["1950-04-01T19:29:59+00:00", "03:29:59", "HKT", -480],
 		["1950-04-01T19:30:00+00:00", "04:30:00", "HKST", -540],
-		["1950-10-28T18:29:59+00:00", "03:29:59", "HKST", -540],
-		["1950-10-28T18:30:00+00:00", "02:30:00", "HKT", -480]
+		["1950-10-28T19:29:59+00:00", "04:29:59", "HKST", -540],
+		["1950-10-28T19:30:00+00:00", "03:30:00", "HKT", -480]
 	]),
 
 	"1951" : helpers.makeTestYear("Hongkong", [
 		["1951-03-31T19:29:59+00:00", "03:29:59", "HKT", -480],
 		["1951-03-31T19:30:00+00:00", "04:30:00", "HKST", -540],
-		["1951-10-27T18:29:59+00:00", "03:29:59", "HKST", -540],
-		["1951-10-27T18:30:00+00:00", "02:30:00", "HKT", -480]
+		["1951-10-27T19:29:59+00:00", "04:29:59", "HKST", -540],
+		["1951-10-27T19:30:00+00:00", "03:30:00", "HKT", -480]
 	]),
 
 	"1952" : helpers.makeTestYear("Hongkong", [
 		["1952-04-05T19:29:59+00:00", "03:29:59", "HKT", -480],
 		["1952-04-05T19:30:00+00:00", "04:30:00", "HKST", -540],
-		["1952-11-01T18:29:59+00:00", "03:29:59", "HKST", -540],
-		["1952-11-01T18:30:00+00:00", "02:30:00", "HKT", -480]
+		["1952-11-01T19:29:59+00:00", "04:29:59", "HKST", -540],
+		["1952-11-01T19:30:00+00:00", "03:30:00", "HKT", -480]
 	]),
 
 	"1953" : helpers.makeTestYear("Hongkong", [
@@ -241,6 +246,8 @@ exports["Hongkong"] = {
 
 	"1979" : helpers.makeTestYear("Hongkong", [
 		["1979-05-12T19:29:59+00:00", "03:29:59", "HKT", -480],
-		["1979-05-12T19:30:00+00:00", "04:30:00", "HKST", -540]
+		["1979-05-12T19:30:00+00:00", "04:30:00", "HKST", -540],
+		["1979-10-20T18:29:59+00:00", "03:29:59", "HKST", -540],
+		["1979-10-20T18:30:00+00:00", "02:30:00", "HKT", -480]
 	])
 };
\ No newline at end of file
