@@ -137,6 +137,20 @@ exports["Israel"] = {
 		["1975-08-30T21:00:00+00:00", "23:00:00", "IST", -120]
 	]),
 
+	"1980" : helpers.makeTestYear("Israel", [
+		["1980-08-01T21:59:59+00:00", "23:59:59", "IST", -120],
+		["1980-08-01T22:00:00+00:00", "01:00:00", "IDT", -180],
+		["1980-09-12T21:59:59+00:00", "00:59:59", "IDT", -180],
+		["1980-09-12T22:00:00+00:00", "00:00:00", "IST", -120]
+	]),
+
+	"1984" : helpers.makeTestYear("Israel", [
+		["1984-05-04T21:59:59+00:00", "23:59:59", "IST", -120],
+		["1984-05-04T22:00:00+00:00", "01:00:00", "IDT", -180],
+		["1984-08-24T21:59:59+00:00", "00:59:59", "IDT", -180],
+		["1984-08-24T22:00:00+00:00", "00:00:00", "IST", -120]
+	]),
+
 	"1985" : helpers.makeTestYear("Israel", [
 		["1985-04-13T21:59:59+00:00", "23:59:59", "IST", -120],
 		["1985-04-13T22:00:00+00:00", "01:00:00", "IDT", -180],
