@@ -95,5 +95,10 @@ exports["Pacific/Rarotonga"] = {
 		["1990-03-04T09:30:00+00:00", "23:30:00", "-10", 600],
 		["1990-10-28T09:59:59+00:00", "23:59:59", "-10", 600],
 		["1990-10-28T10:00:00+00:00", "00:30:00", "-0930", 570]
+	]),
+
+	"1991" : helpers.makeTestYear("Pacific/Rarotonga", [
+		["1991-03-03T09:29:59+00:00", "23:59:59", "-0930", 570],
+		["1991-03-03T09:30:00+00:00", "23:30:00", "-10", 600]
 	])
 };
\ No newline at end of file
