@@ -40,5 +40,10 @@ exports["Pacific/Tongatapu"] = {
 	"2016" : helpers.makeTestYear("Pacific/Tongatapu", [
 		["2016-11-05T12:59:59+00:00", "01:59:59", "+13", -780],
 		["2016-11-05T13:00:00+00:00", "03:00:00", "+14", -840]
+	]),
+
+	"2017" : helpers.makeTestYear("Pacific/Tongatapu", [
+		["2017-01-14T12:59:59+00:00", "02:59:59", "+14", -840],
+		["2017-01-14T13:00:00+00:00", "02:00:00", "+13", -780]
 	])
 };
\ No newline at end of file
