@@ -3,6 +3,11 @@
 var helpers = require("../../helpers/helpers");
 
 exports["US/Indiana-Starke"] = {
+
+	"guess:by:offset" : helpers.makeTestGuess("US/Indiana-Starke", { offset: true, expect: "America/Chicago" }),
+
+	"guess:by:abbr" : helpers.makeTestGuess("US/Indiana-Starke", { abbr: true, expect: "America/Chicago" }),
+
 	"1918" : helpers.makeTestYear("US/Indiana-Starke", [
 		["1918-03-31T07:59:59+00:00", "01:59:59", "CST", 360],
 		["1918-03-31T08:00:00+00:00", "03:00:00", "CDT", 300],
