@@ -272,5 +272,10 @@ exports["W-SU"] = {
 	"2011" : helpers.makeTestYear("W-SU", [
 		["2011-03-26T22:59:59+00:00", "01:59:59", "MSK", -180],
 		["2011-03-26T23:00:00+00:00", "03:00:00", "MSK", -240]
+	]),
+
+	"2014" : helpers.makeTestYear("W-SU", [
+		["2014-10-25T21:59:59+00:00", "01:59:59", "MSK", -240],
+		["2014-10-25T22:00:00+00:00", "01:00:00", "MSK", -180]
 	])
 };
\ No newline at end of file
